/*
 * Copyright (C) 2005-2013 Schlichtherle IT Services.
 * All rights reserved. Use is subject to license terms.
 */
package net.java.truelicense.core.auth;

import java.util.Arrays;
import java.util.Locale;
import javax.annotation.*;
import net.java.truelicense.core.util.Objects;
import static net.java.truelicense.core.util.Objects.*;
import net.java.truelicense.core.util.Strings;

/**
 * Provides typical properties of {@linkplain Repository repositories}.
 * A repository implementation may want to subclass this class for comfort.
 *
 * @author Christian Schlichtherle
 */
@SuppressWarnings("ReturnOfCollectionOrArrayField")
public class RepositorySupport {

    private @CheckForNull String artifactType, artifactTransferEncoding,
            signatureType, signatureTransferEncoding;
    private @CheckForNull byte[] artifactData, signatureData;

    public final @Nullable String getArtifactType() { return artifactType; }

    public final void setArtifactType(final String artifactFormat) {
        this.artifactType = requireNonNull(artifactFormat);
    }

    public final @Nullable String getArtifactTransferEncoding() {
        return artifactTransferEncoding;
    }

    public final void setArtifactTransferEncoding(
            final String artifactTransferEncoding) {
        this.artifactTransferEncoding = requireNonNull(artifactTransferEncoding);
    }

    protected final @Nullable byte[] artifactData() { return artifactData; }

    protected final void artifactData(final byte[] artifactData) {
        this.artifactData = requireNonNull(artifactData);
    }

    public final @Nullable String getSignatureType() { return signatureType; }

    public final void setSignatureType(final String signatureFormat) {
        this.signatureType = requireNonNull(signatureFormat);
    }

    public final @Nullable String getSignatureTransferEncoding() {
        return signatureTransferEncoding;
    }

    public final void setSignatureTransferEncoding(
            final String signatureTransferEncoding) {
        this.signatureTransferEncoding = requireNonNull(signatureTransferEncoding);
    }

    protected final @Nullable byte[] signatureData() { return signatureData; }

    protected final void signatureData(final byte[] signatureData) {
        this.signatureData = requireNonNull(signatureData);
    }

    @Override
    @SuppressWarnings("AccessingNonPublicFieldOfAnotherObject")
    public boolean equals(final Object obj) {
        if (this == obj) return true;
        if (!(obj instanceof RepositorySupport)) return false;
        final RepositorySupport that = (RepositorySupport) obj;
        return  Strings.equalsIgnoreCase(this.artifactType, that.artifactType) &&
                Strings.equalsIgnoreCase(this.artifactTransferEncoding, that.artifactTransferEncoding) &&
                Arrays.equals(this.artifactData, that.artifactData) &&
                Strings.equalsIgnoreCase(this.signatureType, that.signatureType) &&
                Strings.equalsIgnoreCase(this.signatureTransferEncoding, that.signatureTransferEncoding) &&
                Arrays.equals(this.signatureData, that.signatureData);
    }

    @Override
    public int hashCode() {
        int c = 17;
        c = 31 * c + Objects.hashCode(Strings.toLowerCase(artifactType, Locale.ROOT));
        c = 31 * c + Objects.hashCode(Strings.toLowerCase(artifactTransferEncoding, Locale.ROOT));
        c = 31 * c + Arrays.hashCode(artifactData);
        c = 31 * c + Objects.hashCode(Strings.toLowerCase(signatureType, Locale.ROOT));
        c = 31 * c + Objects.hashCode(Strings.toLowerCase(signatureTransferEncoding, Locale.ROOT));
        c = 31 * c + Arrays.hashCode(signatureData);
        return c;
    }
}
